/*
 *
 *      Copyright (c) 2018-2025, avenue All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the pig4cloud.com developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: avenue
 *
 */

package com.emergency.avenue.admin.api.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.time.LocalDateTime;

/**
 * <p>
 * 部门管理
 * </p>
 *
 * @author avenue
 * @since 2018-01-22
 */
@Data
@Schema(description = "部门")
@EqualsAndHashCode(callSuper = true)
public class SysDept extends Model<SysDept> {

	private static final long serialVersionUID = 1L;

	@TableId(value = "dept_id", type = IdType.ASSIGN_ID)
	@Schema(description = "部门id")
	private String deptId;

	/**
	 * 部门名称
	 */
	@NotBlank(message = "部门名称不能为空")
	@Schema(description = "部门名称")
	private String name;

	/**
	 * 部门名称
	 */
	@Schema(description = "部门名称")
	private String abbreviationName;

	/**
	 * 排序
	 */
	@NotNull(message = "排序值不能为空")
	@Schema(description = "排序值")
	private Integer sortOrder;

	/**
	 * 创建人
	 */
	@TableField(fill = FieldFill.INSERT)
	@Schema(description = "创建人")
	private String createBy;

	/**
	 * 修改人
	 */
	@TableField(fill = FieldFill.UPDATE)
	@Schema(description = "修改人")
	private String updateBy;

	/**
	 * 创建时间
	 */
	@Schema(description = "创建时间")
	@TableField(fill = FieldFill.INSERT)
	private LocalDateTime createTime;

	/**
	 * 修改时间
	 */
	@Schema(description = "修改时间")
	@TableField(fill = FieldFill.UPDATE)
	private LocalDateTime updateTime;

	/**
	 * 父级部门id
	 */
	@Schema(description = "父级部门id")
	private String parentId;

	/**
	 * 是否删除 1：已删除 0：正常
	 */
	@TableLogic
	@Schema(description = "删除标记,1:已删除,0:正常")
	@TableField(fill = FieldFill.INSERT)
	private String delFlag;

	/**
	 * 部门类型
	 */
	@Schema(description = "部门类型")
	private String deptType;

	/**
	 * 仓库类型
	 */
	@Schema(description = "仓库类型")
	private String warehouseType;

	/**
	 * 经度
	 */
	@Schema(description = "经度")
	private String longitude;

	/**
	 * 维度
	 */
	@Schema(description = "维度")
	private String dimension;

	/**
	 * 法人信息
	 */
	@Schema(description = "法人信息")
	private String legalPerson;

	/**
	 * 联系电话
	 */
	@Schema(description = "联系电话")
	private String deptPhone;

	/**
	 * 库区图
	 */
	@Schema(description = "库区图")
	private String reservoirImg;

	/**
	 * 省
	 */
	@Schema(description = "省")
	private String deptProvince;

	/**
	 * 市
	 */
	@Schema(description = "市")
	private String deptCity;

	/**
	 * 区
	 */
	@Schema(description = "区")
	private String deptArea;

	/**
	 * 地址
	 */
	@Schema(description = "地址")
	private String deptAddress;

	/**
	 * 合并数组地址
	 */
	@Schema(description = "合并数组地址")
	private String deptMergeAddress;
}
